@@ -16,15 +16,23 @@
 import logging
 
 import grpc
+import typer
 
 from .proto import hello_world_pb2, hello_world_pb2_grpc
 
 
 def say_hello(stub: hello_world_pb2_grpc.HelloWorldStub):
     message = hello_world_pb2.Greeting(content="Hello DICOM-RT AI API server!")
-    reply = stub.talk(message)
+    typer.echo(
+        "You say "
+        + typer.style(f'"{message.content}"', fg=typer.colors.BLUE, bold=True)
+    )
 
-    print(reply)
+    reply: hello_world_pb2.Greeting = stub.talk(message)
+    typer.echo(
+        "The server responds with "
+        + typer.style(f'"{reply.content}"', fg=typer.colors.GREEN, bold=True)
+    )
 
 
 def run():
